==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/OnExpandedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { OnExpandedEventArgsDescription } from "./OnExpandedEventArgsDescription";
/**
 * @hidden
 */
export let OnExpandedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class OnExpandedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (OnExpandedEventArgsDescriptionMetadata.a == null) {
                OnExpandedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                OnExpandedEventArgsDescriptionMetadata.c(OnExpandedEventArgsDescriptionMetadata.a);
            }
            if (a.j(OnExpandedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(OnExpandedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            OnExpandedEventArgsDescriptionMetadata.b(a);
            a.aa("OnExpandedEventArgs", () => new OnExpandedEventArgsDescription());
            a.z("OnExpandedEventArgs", OnExpandedEventArgsDescriptionMetadata.a);
        }
    }
    OnExpandedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(OnExpandedEventArgsDescriptionMetadata, 'OnExpandedEventArgsDescriptionMetadata');
    OnExpandedEventArgsDescriptionMetadata.a = null;
    return OnExpandedEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/OnExpandedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { OnExpandedEventArgsDescription } from "./OnExpandedEventArgsDescription";
/**
 * @hidden
 */
export let OnExpandedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class OnExpandedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (OnExpandedEventArgsDescriptionMetadata.a == null) {
                OnExpandedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                OnExpandedEventArgsDescriptionMetadata.c(OnExpandedEventArgsDescriptionMetadata.a);
            }
            if (a.k(OnExpandedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(OnExpandedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            OnExpandedEventArgsDescriptionMetadata.b(a);
            a.ac("OnExpandedEventArgs", () => new OnExpandedEventArgsDescription());
            a.ab("OnExpandedEventArgs", OnExpandedEventArgsDescriptionMetadata.a);
        }
    }
    OnExpandedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(OnExpandedEventArgsDescriptionMetadata, 'OnExpandedEventArgsDescriptionMetadata');
    OnExpandedEventArgsDescriptionMetadata.a = null;
    return OnExpandedEventArgsDescriptionMetadata;
})();
